@@ -10,5 +10,13 @@ function(object, ...) {
 		class(val) <- "logLik"
 		}
     val
-    }
+}
+
+`logLik.mlbs` <- function(object, ...) {
+	if (object$method == "glm")
+		val <- logLik(object$obj) else
+		{val <- object$logLik
+		attr(val, "df") <- length(object$par) + 1 		}
+	    val
+}
 
